@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( uninitialized once );
 
-our $VERSION = '1.839';
+our $VERSION = '1.840';
 
 use base 'MCE::Channel';
 use MCE::Mutex ();
@@ -328,7 +328,7 @@ MCE::Channel::Mutex - Channel for producer(s) and many consumers
 
 =head1 VERSION
 
-This document describes MCE::Channel::Mutex version 1.839
+This document describes MCE::Channel::Mutex version 1.840
 
 =head1 DESCRIPTION
 
@@ -338,13 +338,13 @@ for processes and threads. Locking is handled using MCE::Mutex.
  use MCE::Channel;
 
  # The default is tuned for one producer and many consumers.
- my $chnl_a = MCE::Channel->new( impl => 'mutex' );
+ my $chnl_a = MCE::Channel->new( impl => 'Mutex' );
 
  # Specify the 'mp' option for safe use by two or more producers
  # sending or recieving on the left side of the channel.
  # E.g. C<->enqueue/->send> or C<->recv2/->recv2_nb>
 
- my $chnl_b = MCE::Channel->new( impl => 'mutex', mp => 1 );
+ my $chnl_b = MCE::Channel->new( impl => 'Mutex', mp => 1 );
 
 The API is described in L<MCE::Channel>.
 
